==> glpi_0.78.5.orig.tar.gz: glpi/inc/notificationinterface.class.php <==
<?php
/*
 * @version $Id: notificationinterface.class.php 10764 2010-02-24 19:24:03Z yllen $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file:
// Purpose of file:
// ----------------------------------------------------------------------

if (!defined('GLPI_ROOT')) {
   die("Sorry. You can't access directly to this file");
}

/**
 *  Interface to implement for each notification mode
 */
interface NotificationInterface {

   /**
    * Send notifications
    * @return must return 0 or 1
    */
   function sendNotification();


   /**
    * Check user address
    * @param $address the user's address to check
    * @param $options an array with the special options (may be needed)
    *
    * @return true or false
    */
   static function isUserAddressValid($address, $options = array());


   /**
    * Method to test notification
    */
   static function testNotification();
}

?>

==> glpi_0.80.1.orig.tar.gz: glpi/inc/notificationinterface.class.php <==
<?php
/*
 * @version $Id: notificationinterface.class.php 14684 2011-06-11 06:32:40Z remi $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2011 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file:
// Purpose of file:
// ----------------------------------------------------------------------

if (!defined('GLPI_ROOT')) {
   die("Sorry. You can't access directly to this file");
}

/**
 *  Interface to implement for each notification mode
 */
interface NotificationInterface {

   /**
    * Send notifications
    * @return must return 0 or 1
    */
   function sendNotification();


   /**
    * Check user address
    * @param $address the user's address to check
    * @param $options an array with the special options (may be needed)
    *
    * @return true or false
    */
   static function isUserAddressValid($address, $options = array());


   /**
    * Method to test notification
    */
   static function testNotification();
}

?>
